@@ -20,22 +20,20 @@
  * along with this package. If not, see <http://www.gnu.org/licenses/>.
  **********************************************************************/
 
-
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
 #include <QMessageBox>
 #include <QProcess>
-#include <QTimer>
 #include <QSettings>
+#include <QTimer>
 
 #include <cmd.h>
 
 class QFile;
 
-const QString cli_utils = ". /usr/local/lib/cli-shell-utils/cli-shell-utils.bash;";
-
-namespace Ui {
+namespace Ui
+{
 class MainWindow;
 }
 
@@ -44,63 +42,59 @@ class MainWindow : public QDialog
     Q_OBJECT
 
 public:
-    MainWindow(const QStringList &args);
+    MainWindow(const QStringList &args, QDialog *parent = nullptr);
     ~MainWindow();
 
-    bool checkDestSize();
-    bool isRunningLive();
-    bool isToRam();
-    void makeUsb(const QString &options);
-    void progress();
-    void setup();
+    QString LUM;
     QString buildOptionList();
     QStringList buildUsbList();
-    QStringList removeUnsuitable(const QStringList &devices); // remove unsuitable disks from the list (live and unremovable)
-    QString LUM;
-
+    QStringList removeUnsuitable(const QStringList &devices); // remove unsuitable disks (live and unremovable)
+    bool checkDestSize();
+    bool isRunningLive();
+    const QString cli_utils {". /usr/local/lib/cli-shell-utils/cli-shell-utils.bash;"};
+    static bool isToRam();
+    void makeUsb(const QString &options);
+    void progress();
+    void setGeneralConnections();
+    void setup();
 
 public slots:
 
 private slots:
-    bool isantiX_mx_family(QString arg1);
+    static bool isantiX_mx_family(const QString &bselected);
     void cleanup();
-    void cmdStart();
     void cmdDone();
     void setConnections();
     void setDefaultMode(const QString &iso_name);
     void updateBar();
     void updateOutput();
 
-    void on_buttonAbout_clicked();
-    void on_buttonBack_clicked();
-    void on_buttonHelp_clicked();
-    void on_buttonNext_clicked();
-    void on_buttonOptions_clicked();
-    void on_buttonRefresh_clicked();
-    void on_buttonSelectSource_clicked();
-    void on_cb_clone_live_clicked(bool checked);
-    void on_cb_clone_mode_clicked(bool checked);
-    void on_cb_data_first_clicked(bool checked);
-    void on_cb_update_clicked(bool checked);
-    void on_edit_label_textChanged(QString arg1);
-    void on_pushButtonLumLogFile_clicked();
-    void on_rb_dd_clicked();
-    void on_rb_normal_clicked();
-    void on_spinBoxSize_valueChanged(int arg1);
-//    void on_buttonEnter_clicked();
-//    void on_lineEdit_returnPressed();
+    void checkCloneLive_clicked(bool checked);
+    void checkCloneMode_clicked(bool checked);
+    void checkDataFirst_clicked(bool checked);
+    void checkUpdate_clicked(bool checked);
+    void pushAbout_clicked();
+    void pushBack_clicked();
+    void pushHelp_clicked();
+    void pushLumLogFile_clicked();
+    void pushNext_clicked();
+    void pushOptions_clicked();
+    void pushRefresh_clicked();
+    void pushSelectSource_clicked();
+    void radioDd_clicked();
+    void radioNormal_clicked();
+    void spinBoxSize_valueChanged(int arg1);
+    void textLabel_textChanged(QString arg1);
 
 private:
     Ui::MainWindow *ui;
     Cmd cmd;
-    QFile *stat_file;
+    QFile *stat_file {};
     QString device;
     QTimer timer;
-    bool advancedOptions;
-    int height;
+    bool advancedOptions {};
+    int height {};
     uint size_check;
 };
 
-
 #endif
-
